package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppCheckImage;
import com.ruoyi.model.vo.AppCheckImageVo;

/**
 * 打卡图片Service接口
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
public interface IAppCheckImageService 
{
    /**
     * 查询打卡图片
     * 
     * @param checkImageId 打卡图片主键
     * @return 打卡图片
     */
    public AppCheckImage selectAppCheckImageByCheckImageId(Long checkImageId);

    /**
     * 查询打卡图片列表
     * 
     * @param appCheckImage 打卡图片
     * @return 打卡图片集合
     */
    public List<AppCheckImage> selectAppCheckImageList(AppCheckImage appCheckImage);

    /**
     * 新增打卡图片
     * 
     * @param appCheckImage 打卡图片
     * @return 结果
     */
    public int insertAppCheckImage(AppCheckImage appCheckImage);

    /**
     * 修改打卡图片
     * 
     * @param appCheckImage 打卡图片
     * @return 结果
     */
    public int updateAppCheckImage(AppCheckImage appCheckImage);

    /**
     * 批量删除打卡图片
     * 
     * @param checkImageIds 需要删除的打卡图片主键集合
     * @return 结果
     */
    public int deleteAppCheckImageByCheckImageIds(Long[] checkImageIds);

    /**
     * 删除打卡图片信息
     * 
     * @param checkImageId 打卡图片主键
     * @return 结果
     */
    public int deleteAppCheckImageByCheckImageId(Long checkImageId);

    /**
     * 查询打卡图片及其类型列表
     *
     * @return 打卡图片及其类型集合
     */
    public List<AppCheckImageVo> getAppCheckImageList();
}
